%define api	7.10

%bcond_without doc

Summary:	The official C++ client API for PostgreSQL
Name:		libpqxx
Version:	7.10.0
Release:	%mkrel 1
License:	GPLv2+
Group:		Development/Databases
Url:		https://pqxx.org/
Source0:	https://github.com/jtv/libpqxx/archive/%version/%name-%version.tar.gz
BuildRequires:	cmake
BuildRequires:	ninja
BuildRequires:	pkgconfig(libpq)
%if %{with doc}
BuildRequires:	doxygen
BuildRequires:	graphviz
BuildRequires:	xmlto
%endif

%description
This library works on top of the C-level API library, libpq. You will need
libpq in order to use libpqxx.

The first thing you're likely to notice in programming with libpqxx is that
unlike other libraries, it revolves entirely around transactions. Transactions
are a central concept in database management systems, but they are widely
underappreciated among application developers. Another well-known open source
database system, MySQL, never even got around to implementing them at all in
their own engine, relying on a third-party replacement engine (now owned by
Oracle) to provide this functionality instead.

%package devel
Summary:        Headers for developing programs that will use %{name}
Group:          Development/C++
Requires:       %{name} = %{version}-%{release}

%description devel
This package contains the headers that programmers will need to develop
applications which will use %{name}.

%if %{with doc}
%package doc
Summary:        Developer documentation for %{name}
Group:          Documentation
BuildArch:      noarch

%description doc
Developer documentation for %{name}.
%endif

%prep
%autosetup -p1

# fix spurious permissions
chmod -x COPYING

%build
%cmake -G Ninja \
        %if %{with doc}
        -DBUILD_DOC=ON
        %endif
%cmake_build

%install
%cmake_install

%files
%doc AUTHORS NEWS README.md VERSION
%license COPYING
%_libdir/libpqxx-%{api}.so

%files devel
%_includedir/pqxx/
%_libdir/libpqxx.so
%_libdir/pkgconfig/libpqxx.pc
%_libdir/cmake/libpqxx/

%if %{with doc}
%files doc
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/accessing-results.md
%{_docdir}/%{name}/datatypes.md
%{_docdir}/%{name}/escaping.md
%{_docdir}/%{name}/getting-started.md
%{_docdir}/%{name}/mainpage.md
%{_docdir}/%{name}/performance.md
%{_docdir}/%{name}/prepared-statement.md
%{_docdir}/%{name}/streams.md
%{_docdir}/%{name}/thread-safety.md
%{_docdir}/%{name}/html
%{_docdir}/%{name}/binary-data.md
%{_docdir}/%{name}/parameters.md
%endif


%changelog
* Sat Dec 28 2024 daviddavid <daviddavid> 7.10.0-1.mga10
+ Revision: 2130767
- new version: 7.10.0
- new version: 7.9.1

* Mon Oct 03 2022 joequant <joequant> 7.7.4-1.mga9
+ Revision: 1894339
- update to 7.7.4

* Thu Mar 31 2022 umeabot <umeabot> 7.3.0-2.mga9
+ Revision: 1836883
- Mageia 9 Mass Rebuild

* Fri Dec 18 2020 joequant <joequant> 7.3.0-1.mga8
+ Revision: 1660871
- update to 7.3.0

* Sun May 10 2020 daviddavid <daviddavid> 7.0.7-1.mga8
+ Revision: 1582458
- new version: 7.0.7

* Fri May 01 2020 daviddavid <daviddavid> 7.0.6-1.mga8
+ Revision: 1577464
- new version: 7.0.6

* Tue Mar 24 2020 daviddavid <daviddavid> 7.0.5-1.mga8
+ Revision: 1559182
- new version: 7.0.5

* Fri Feb 21 2020 daviddavid <daviddavid> 7.0.2-1.mga8
+ Revision: 1548825
- new version: 7.0.2

* Thu Feb 20 2020 umeabot <umeabot> 7.0.1-2.mga8
+ Revision: 1547385
- Mageia 8 Mass Rebuild

* Sun Feb 09 2020 daviddavid <daviddavid> 7.0.1-1.mga8
+ Revision: 1488116
- new version: 7.0.1
- switch to cmake build system
- compile docs

* Sat Feb 01 2020 daviddavid <daviddavid> 6.4.5-1.mga8
+ Revision: 1486223
- new version: 6.4.5
- fix owner of include dir
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Sep 23 2018 umeabot <umeabot> 4.0.1-10.mga7
+ Revision: 1299097
- Mageia 7 Mass Rebuild

* Sat Jun 09 2018 wally <wally> 4.0.1-9.mga7
+ Revision: 1235760
- fix build on aarch64

* Sun May 06 2018 daviddavid <daviddavid> 4.0.1-8.mga7
+ Revision: 1226751
- add patch to fix linker issue during configure

* Thu Feb 11 2016 umeabot <umeabot> 4.0.1-7.mga6
+ Revision: 955617
- Mageia 6 Mass Rebuild

* Wed Aug 26 2015 fwang <fwang> 4.0.1-6.mga6
+ Revision: 869475
- rebuild for gcc5

* Tue Nov 25 2014 cjw <cjw> 4.0.1-5.mga5
+ Revision: 798949
- rebuild against postgresql9.4

* Wed Oct 15 2014 umeabot <umeabot> 4.0.1-4.mga5
+ Revision: 738916
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 4.0.1-3.mga5
+ Revision: 681717
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 4.0.1-2.mga4
+ Revision: 531331
- Mageia 4 Mass Rebuild

* Sun Aug 04 2013 fwang <fwang> 4.0.1-1.mga4
+ Revision: 463114
- new version 4.0.1

* Sat Jan 12 2013 umeabot <umeabot> 4.0-2.mga3
+ Revision: 357988
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 04 2011 fwang <fwang> 4.0-1.mga2
+ Revision: 175969
- new version 4.0

* Fri Feb 11 2011 ahmad <ahmad> 3.1-3.mga1
+ Revision: 50400
- drop old/unneeded scriptlets
- don't ship .la
- imported package libpqxx


* Sun Nov 28 2010 Oden Eriksson <oeriksson@mandriva.com> 3.1-2mdv2011.0
+ Revision: 602596
- rebuild

* Tue Feb 16 2010 Funda Wang <fwang@mandriva.org> 3.1-1mdv2010.1
+ Revision: 506436
- drop old patches
- new version 3.1

* Wed Dec 09 2009 Funda Wang <fwang@mandriva.org> 3.0.2-1mdv2010.1
+ Revision: 475325
- new version 3.0.2

* Wed Sep 02 2009 Christophe Fergeau <cfergeau@mandriva.com> 2.6.9-7mdv2010.0
+ Revision: 425690
- rebuild

* Sun Dec 21 2008 Oden Eriksson <oeriksson@mandriva.com> 2.6.9-6mdv2009.1
+ Revision: 317030
- rebuild

* Wed Aug 06 2008 Thierry Vignaud <tv@mandriva.org> 2.6.9-5mdv2009.0
+ Revision: 264890
- rebuild early 2009.0 package (before pixel changes)

* Thu Jun 12 2008 Anssi Hannula <anssi@mandriva.org> 2.6.9-4mdv2009.0
+ Revision: 218535
- fix undefined symbol errors by making freemem_result_data public (P4
  from upstream)
- fix tests for cleaned gcc 4.3 c++ headers (P3)

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Wed May 21 2008 Oden Eriksson <oeriksson@mandriva.com> 2.6.9-3mdv2009.0
+ Revision: 209722
- added a gcc43 patch from fedora

* Mon Feb 18 2008 Thierry Vignaud <tv@mandriva.org> 2.6.9-2mdv2008.1
+ Revision: 170954
- rebuild
- fix "foobar is blabla" summary (=> "blabla") so that it looks nice in rpmdrake
- fix description-line-too-long

* Sat Feb 02 2008 Funda Wang <fwang@mandriva.org> 2.6.9-1mdv2008.1
+ Revision: 161377
- New version 2.6.9
- Move main.so into main package

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild
    - kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot


* Sat Jan 13 2007 Olivier Thauvin <nanardon@mandriva.org> 2.6.8-4mdv2007.0
+ Revision: 108358
- rebuild for latest libpq

* Mon Dec 11 2006 Nicolas Lécureuil <neoclust@mandriva.org> 2.6.8-3mdv2007.1
+ Revision: 94800
- Add BuildRequires
- Rebuild

* Thu Nov 16 2006 Laurent Montel <lmontel@mandriva.com> 2.6.8-2mdv2007.1
+ Revision: 84676
- Add buildrequires
- Import libpqxx

